@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.volume_snapshot import VolumeSnapshot
 
 
 @pytest.mark.incremental
 class TestVolumeSnapshot:
     @pytest.fixture(scope="class")
-    def volumesnapshot(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def volumesnapshot(self, client):
         return VolumeSnapshot(
-            client=fake_client,
+            client=client,
             name="test-volumesnapshot",
             namespace="default",
             source={"test-source": "test-value"},
